==> camel-k-sources-1.10.4.tar.gz: camel-k-1.10.4/pkg/util/command_test.go <==
/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package util

import (
	"context"
	"fmt"
	"os/exec"
	"strings"
	"testing"

	"github.com/stretchr/testify/assert"
)

var (
	loggerInfo = func(s string) string {
		fmt.Println("OUT:", s)
		if strings.Contains(s, "invalid") {
			return s
		}
		return ""
	}
	loggerError = func(s string) string {
		fmt.Println("ERR:", s)
		if strings.Contains(s, "invalid") {
			return s
		}
		return ""
	}
)

func TestRunAndLog(t *testing.T) {
	cmd := exec.CommandContext(context.Background(), "date")
	err := RunAndLog(context.Background(), cmd, loggerInfo, loggerError)

	assert.Nil(t, err)
}

func TestRunAndLogInvalid(t *testing.T) {
	cmd := exec.CommandContext(context.Background(), "date", "-dsa")
	err := RunAndLog(context.Background(), cmd, loggerInfo, loggerError)

	assert.NotNil(t, err)
	assert.ErrorContains(t, err, "exit status 1")
}

==> camel-k-sources-1.12.1.tar.gz: camel-k-1.12.1/pkg/util/command_test.go <==
/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package util

import (
	"context"
	"fmt"
	"os/exec"
	"testing"

	"github.com/stretchr/testify/assert"
)

var (
	loggerInfo = func(s string) string {
		fmt.Println("OUT:", s)
		return s
	}
	loggerError = func(s string) string {
		fmt.Println("ERR:", s)
		return s
	}
)

func TestRunAndLog(t *testing.T) {
	cmd := exec.CommandContext(context.Background(), "date")
	err := RunAndLog(context.Background(), cmd, loggerInfo, loggerError)

	assert.Nil(t, err)
}

func TestRunAndLogInvalid(t *testing.T) {
	cmd := exec.CommandContext(context.Background(), "go", "help", "dsa")
	err := RunAndLog(context.Background(), cmd, loggerInfo, loggerError)

	assert.NotNil(t, err)
	assert.Equal(t, "go help dsa: unknown help topic. Run 'go help'.: exit status 2", err.Error())
}
